Display

Trait Display 

1.6.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Implementors

Source

impl Display for DecodeError

Source

impl Display for hashbrown::TryReserveError

Source

impl Display for indexmap::GetDisjointMutError

Source

impl Display for Level

Source

impl Display for LevelFilter

Source

impl Display for postcard::error::Error

Source

impl Display for CollectionAllocErr

Source

impl Display for target_lexicon::parse_error::ParseError

Source

impl Display for Aarch64Architecture

Source

impl Display for Architecture

Source

impl Display for ArmArchitecture

Source

impl Display for BinaryFormat

Source

impl Display for Environment

Source

impl Display for Mips32Architecture

Source

impl Display for Mips64Architecture

Source

impl Display for OperatingSystem

Source

impl Display for Riscv32Architecture

Source

impl Display for Riscv64Architecture

Source

impl Display for Vendor

Source

impl Display for X86_32Architecture

Source

impl Display for BigEndian

Source

impl Display for LittleEndian

Source

impl Display for CompileError

Source

impl Display for EngineOrModuleTypeIndex

Source

impl Display for FlagValue<'_>

Source

impl Display for Trap

Source

impl Display for WasmCompositeType

Source

impl Display for WasmError

Source

impl Display for WasmHeapType

Source

impl Display for WasmStorageType

Source

impl Display for WasmValType



impl Display for PrimitiveValType



impl Display for StorageType



impl Display for UnpackedIndex



impl Display for ValType

Source

impl Display for AsciiChar

1.34.0 · Source

impl Display for Infallible

1.17.0 · Source

impl Display for FromBytesWithNulError

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for SocketAddr

1.86.0 · Source

impl Display for wasmtime_environ::__core::slice::GetDisjointMutError

1.0.0 · Source

impl Display for VarError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.60.0 · Source

impl Display for ErrorKind

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

Source

impl Display for !

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl Display for anyhow::Error

Source

impl Display for bitflags::parser::ParseError

Source

impl Display for DestBufTooSmallError

Source

impl Display for getrandom::error::Error

Source

impl Display for indexmap::TryReserveError

Source

impl Display for ParseLevelError

Source

impl Display for SetLoggerError

Source

impl Display for object::read::Error

Source

impl Display for SectionIndex

Source

impl Display for SymbolIndex

Source

impl Display for object::write::Error

Source

impl Display for serde_core::de::value::Error

Source

impl Display for Triple

1.0.0 · Source

impl Display for String

Source

impl Display for SizeOverflow

Source

impl Display for WasmArrayType

Source

impl Display for WasmFieldType

Source

impl Display for WasmFuncType

Source

impl Display for WasmRefType

Source

impl Display for WasmStructType

Source

impl Display for WasmSubType



impl Display for ComponentName



impl Display for KebabStr



impl Display for KebabString



impl Display for BinaryReaderError



impl Display for CompositeType



impl Display for PackedIndex



impl Display for RefType



impl Display for SubType

Source

impl Display for wasmtime_environ::__core::alloc::AllocError

1.28.0 · Source

impl Display for LayoutError

1.35.0 · Source

impl Display for TryFromSliceError

1.39.0 · Source

impl Display for wasmtime_environ::__core::ascii::EscapeDefault

Source

impl Display for ByteStr

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

1.34.0 · Source

impl Display for CharTryFromError

1.9.0 · Source

impl Display for DecodeUtf16Error

1.20.0 · Source

impl Display for wasmtime_environ::__core::char::EscapeDebug

1.16.0 · Source

impl Display for wasmtime_environ::__core::char::EscapeDefault

1.16.0 · Source

impl Display for wasmtime_environ::__core::char::EscapeUnicode

1.20.0 · Source

impl Display for ParseCharError

1.16.0 · Source

impl Display for ToLowercase

1.16.0 · Source

impl Display for ToUppercase

1.59.0 · Source

impl Display for TryFromCharError

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.4.0 · Source

impl Display for AddrParseError

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

1.0.0 · Source

impl Display for ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

1.34.0 · Source

impl Display for TryFromIntError

1.26.0 · Source

impl Display for Location<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.0.0 · Source

impl Display for ParseBoolError

1.0.0 · Source

impl Display for Utf8Error

1.66.0 · Source

impl Display for TryFromFloatSecsError

Source

impl Display for ByteString

Source

impl Display for UnorderedKeyError

1.57.0 · Source

impl Display for alloc::collections::TryReserveError

1.58.0 · Source

impl Display for FromVecWithNulError

1.7.0 · Source

impl Display for IntoStringError

1.0.0 · Source

impl Display for NulError

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.65.0 · Source

impl Display for Backtrace

1.0.0 · Source

impl Display for JoinPathsError

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.56.0 · Source

impl Display for WriterPanicked

1.0.0 · Source

impl Display for std::io::error::Error

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for NormalizeError

1.7.0 · Source

impl Display for StripPrefixError

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

1.0.0 · Source

impl Display for RecvError

Source

impl Display for WouldBlock

1.26.0 · Source

impl Display for AccessError

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for semver::parse::Error

Source

impl Display for BuildMetadata

Source

impl Display for Comparator

Source

impl Display for Prerelease

Source

impl Display for Version

Source

impl Display for VersionReq

1.0.0 · Source

impl Display for Arguments<'_>

1.0.0 · Source

impl Display for wasmtime_environ::__core::fmt::Error



impl Display for AllocError



impl Display for ConvertError



impl Display for DwAccess



impl Display for DwAddr



impl Display for DwAt



impl Display for DwAte



impl Display for DwCc



impl Display for DwCfa



impl Display for DwChildren



impl Display for DwDefaulted



impl Display for DwDs



impl Display for DwDsc



impl Display for DwEhPe



impl Display for DwEnd



impl Display for DwForm



impl Display for DwId



impl Display for DwIdx



impl Display for DwInl



impl Display for DwLang



impl Display for DwLle



impl Display for DwLnct



impl Display for DwLne



impl Display for DwLns



impl Display for DwMacro



impl Display for DwOp



impl Display for DwOrd



impl Display for DwRle



impl Display for DwSect



impl Display for DwSectV2



impl Display for DwTag



impl Display for DwUt



impl Display for DwVirtuality



impl Display for DwVis



impl Display for Error



impl Display for Error



impl Display for TryReserveError

Source

impl Display for dyn Expected + '_

Source

impl<'a> Display for Unexpected<'a>

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for wasmtime_environ::__core::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for wasmtime_environ::__core::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for wasmtime_environ::__core::str::EscapeUnicode<'a>

Source

impl<'a, K, V, A> Display for alloc::collections::btree::map::entry::OccupiedError<'a, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

Source

impl<'a, K, V, A> Display for std::collections::hash::map::OccupiedError<'a, K, V, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<'a, K, V, S, A> Display for hashbrown::map::OccupiedError<'a, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<A, S, V> Display for zerocopy::error::ConvertError<A, S, V>
where A: Display, S: Display, V: Display,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<E> Display for Report<E>
where E: Error,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<O> Display for F32<O>
where O: ByteOrder,

Source

impl<O> Display for F64<O>
where O: ByteOrder,

Source

impl<O> Display for I16<O>
where O: ByteOrder,

Source

impl<O> Display for I32<O>
where O: ByteOrder,

Source

impl<O> Display for I64<O>
where O: ByteOrder,

Source

impl<O> Display for I128<O>
where O: ByteOrder,

Source

impl<O> Display for Isize<O>
where O: ByteOrder,

Source

impl<O> Display for U16<O>
where O: ByteOrder,

Source

impl<O> Display for U32<O>
where O: ByteOrder,

Source

impl<O> Display for U64<O>
where O: ByteOrder,

Source

impl<O> Display for U128<O>
where O: ByteOrder,

Source

impl<O> Display for Usize<O>
where O: ByteOrder,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,



impl<R, Offset> Display for LineInstruction<R, Offset>
where R: Reader<Offset = Offset>, Offset: ReaderOffset,

Source

impl<Src, Dst> Display for AlignmentError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for SizeError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for ValidityError<Src, Dst>
where Dst: KnownLayout + TryFromBytes + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<T> Display for SendTimeoutError<T>

1.0.0 · Source

impl<T> Display for TrySendError<T>

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for Unalign<T>
where T: Unaligned + Display,

1.20.0 · Source

impl<T> Display for wasmtime_environ::__core::cell::Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for SendError<T>

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T, A> Display for wasmtime_environ::prelude::Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,



impl<T, A> Display for Box<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, B> Display for zerocopy::ref::def::Ref<B, T>

1.0.0 · Source

impl<W> Display for IntoInnerError<W>